from .BaseApi import BaseApi
from .NamedEndpoint import NamedEndpoint
from .ChampionApiV3 import ChampionApiV3
from .LolStatusApiV3 import LolStatusApiV3
from .DataDragonApi import DataDragonApi

from .ChampionMasteryApiV4 import ChampionMasteryApiV4
from .LeagueApiV4 import LeagueApiV4
from .MatchApiV4 import MatchApiV4
from .SpectatorApiV4 import SpectatorApiV4
from .SummonerApiV4 import SummonerApiV4
from .ThirdPartyCodeApiV4 import ThirdPartyCodeApiV4

__all__ = [
    "BaseApi",
    "NamedEndpoint",
    "ChampionApiV3",
    "LolStatusApiV3",
    "DataDragonApi",
    "ChampionMasteryApiV4",
    "LeagueApiV4",
    "MatchApiV4",
    "SpectatorApiV4",
    "SummonerApiV4",
    "ThirdPartyCodeApiV4",
]
